@@ -7,7 +7,7 @@
  *  See also http://www.freebsd.org/copyright/freebsd-license.html
  *  --------
  *
- *  Copyright (C) 2009-2015 Erwin Waterlander
+ *  Copyright (C) 2009-2016 Erwin Waterlander
  *  Copyright (C) 1998 Christian Wurll
  *  Copyright (C) 1998 Bernd Johannes Wuebben
  *  Copyright (C) 1994-1995 Benjamin Lin.
@@ -76,12 +76,12 @@
 
 void PrintLicense(void)
 {
-  printf("%s", _("\
-Copyright (C) 2009-2015 Erwin Waterlander\n\
+  D2U_ANSI_FPRINTF(stdout,_("\
+Copyright (C) 2009-%d Erwin Waterlander\n\
 Copyright (C) 1998      Christian Wurll (Version 3.1)\n\
 Copyright (C) 1998      Bernd Johannes Wuebben (Version 3.0)\n\
 Copyright (C) 1994-1995 Benjamin Lin\n\
-All rights reserved.\n\n"));
+All rights reserved.\n\n"),2016);
   PrintBSDLicense();
 }
 
@@ -208,8 +208,8 @@ int ConvertDosToUnixW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
-              d2u_fprintf(stderr, "%s: ", progname);
-              d2u_fprintf(stderr, _("Binary symbol 0x00%02X found at line %u\n"),TempChar, line_nr);
+              D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+              D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x00%02X found at line %u\n"),TempChar, line_nr);
             }
             break;
           }
@@ -245,8 +245,8 @@ int ConvertDosToUnixW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
-              d2u_fprintf(stderr, "%s: ", progname);
-              d2u_fprintf(stderr, _("Binary symbol 0x00%02X found at line %u\n"), TempChar, line_nr);
+              D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+              D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x00%02X found at line %u\n"), TempChar, line_nr);
             }
             break;
           }
@@ -301,16 +301,16 @@ int ConvertDosToUnixW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *prog
       default: /* unknown FromToMode */
       ;
 #if DEBUG
-      d2u_fprintf(stderr, "%s: ", progname);
-      d2u_fprintf(stderr, _("program error, invalid conversion mode %d\n"),ipFlag->FromToMode);
+      D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+      D2U_UTF8_FPRINTF(stderr, _("program error, invalid conversion mode %d\n"),ipFlag->FromToMode);
       exit(1);
 #endif
     }
     if (ipFlag->status & UNICODE_CONVERSION_ERROR)
         ipFlag->line_nr = line_nr;
     if ((RetVal == 0) && (ipFlag->verbose > 1)) {
-      d2u_fprintf(stderr, "%s: ", progname);
-      d2u_fprintf(stderr, _("Converted %u out of %u line breaks.\n"), converted, line_nr -1);
+      D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+      D2U_UTF8_FPRINTF(stderr, _("Converted %u out of %u line breaks.\n"), converted, line_nr -1);
     }
     return RetVal;
 }
@@ -367,8 +367,8 @@ int ConvertDosToUnix(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
       ConvTable = D2UAsciiTable;
 
     if ((ipFlag->ConvMode > CONVMODE_7BIT) && (ipFlag->verbose)) { /* not ascii or 7bit */
-       d2u_fprintf(stderr, "%s: ", progname);
-       d2u_fprintf(stderr, _("using code page %d.\n"), ipFlag->ConvMode);
+       D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+       D2U_UTF8_FPRINTF(stderr, _("using code page %d.\n"), ipFlag->ConvMode);
     }
 
     /* CR-LF -> LF */
@@ -391,8 +391,8 @@ int ConvertDosToUnix(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
-              d2u_fprintf(stderr, "%s: ", progname);
-              d2u_fprintf(stderr, _("Binary symbol 0x%02X found at line %u\n"),TempChar, line_nr);
+              D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+              D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x%02X found at line %u\n"),TempChar, line_nr);
             }
             break;
           }
@@ -428,8 +428,8 @@ int ConvertDosToUnix(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
             ipFlag->status |= BINARY_FILE ;
             if (ipFlag->verbose) {
               if ((ipFlag->stdio_mode) && (!ipFlag->error)) ipFlag->error = 1;
-              d2u_fprintf(stderr, "%s: ", progname);
-              d2u_fprintf(stderr, _("Binary symbol 0x%02X found at line %u\n"),TempChar, line_nr);
+              D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+              D2U_UTF8_FPRINTF(stderr, _("Binary symbol 0x%02X found at line %u\n"),TempChar, line_nr);
             }
             break;
           }
@@ -484,14 +484,14 @@ int ConvertDosToUnix(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progn
       default: /* unknown FromToMode */
       ;
 #if DEBUG
-      d2u_fprintf(stderr, "%s: ", progname);
-      d2u_fprintf(stderr, _("program error, invalid conversion mode %d\n"),ipFlag->FromToMode);
+      D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+      D2U_UTF8_FPRINTF(stderr, _("program error, invalid conversion mode %d\n"),ipFlag->FromToMode);
       exit(1);
 #endif
     }
     if ((RetVal == 0) && (ipFlag->verbose > 1)) {
-      d2u_fprintf(stderr, "%s: ", progname);
-      d2u_fprintf(stderr, _("Converted %u out of %u line breaks.\n"),converted, line_nr -1);
+      D2U_UTF8_FPRINTF(stderr, "%s: ", progname);
+      D2U_UTF8_FPRINTF(stderr, _("Converted %u out of %u line breaks.\n"),converted, line_nr -1);
     }
     return RetVal;
 }
@@ -521,8 +521,8 @@ int main (int argc, char *argv[])
       if (strlen(ptr) < sizeof(localedir))
          strcpy(localedir,ptr);
       else {
-         d2u_fprintf(stderr,"%s: ",progname);
-         d2u_ansi_fprintf(stderr, "%s", _("error: Value of environment variable DOS2UNIX_LOCALEDIR is too long.\n"));
+         D2U_UTF8_FPRINTF(stderr,"%s: ",progname);
+         D2U_ANSI_FPRINTF(stderr, "%s", _("error: Value of environment variable DOS2UNIX_LOCALEDIR is too long.\n"));
          strcpy(localedir,LOCALEDIR);
       }
    }
@@ -530,8 +530,16 @@ int main (int argc, char *argv[])
 
 #if defined(ENABLE_NLS) || (defined(D2U_UNICODE) && !defined(__MSDOS__) && !defined(_WIN32) && !defined(__OS2__))
 /* setlocale() is also needed for nl_langinfo() */
+#if (defined(_WIN32) && !defined(__CYGWIN__))
+/* When the locale is set to "" on Windows all East-Asian multi-byte ANSI encoded text is printed
+   wrongly when you use standard printf(). Also UTF-8 code is printed wrongly. See also test/setlocale.c.
+   When we set the locale to "C" gettext still translates the messages on Windows. On Unix this would disable
+   gettext. */
+   setlocale (LC_ALL, "C");
+#else
    setlocale (LC_ALL, "");
 #endif
+#endif
 
 #ifdef ENABLE_NLS
    bindtextdomain (PACKAGE, localedir);
@@ -542,8 +550,8 @@ int main (int argc, char *argv[])
   /* variable initialisations */
   pFlag = (CFlag*)malloc(sizeof(CFlag));
   if (pFlag == NULL) {
-    d2u_fprintf(stderr, "dos2unix:");
-    d2u_ansi_fprintf(stderr, " %s\n", strerror(errno));
+    D2U_UTF8_FPRINTF(stderr, "dos2unix:");
+    D2U_ANSI_FPRINTF(stderr, " %s\n", strerror(errno));
     return errno;
   }
   pFlag->FromToMode = FROMTO_DOS2UNIX;  /* default dos2unix */
@@ -569,8 +577,8 @@ int main (int argc, char *argv[])
 
   argv_glob = (char ***)malloc(sizeof(char***));
   if (argv_glob == NULL) {
-    d2u_fprintf(stderr, "%s:", progname);
-    d2u_ansi_fprintf(stderr, " %s\n", strerror(errno));
+    D2U_UTF8_FPRINTF(stderr, "%s:", progname);
+    D2U_ANSI_FPRINTF(stderr, " %s\n", strerror(errno));
     return errno;
   }
   /* Glob the arguments and convert them to UTF-8 */
